//
//  SSSinaWeiboUserInfoReader.h
//  SinaWeiboConnection
//
//  Created by 冯 鸿杰 on 13-10-18.
//  Copyright (c) 2013年 掌淘科技. All rights reserved.
//

#import <Foundation/Foundation.h>

@class SSSinaWeiboStatusInfoReader;

/**
 *	@brief	用户信息读取器
 */
@interface SSSinaWeiboUserInfoReader : NSObject
{
@private
    NSDictionary *_sourceData;
}

/**
 *	@brief	源数据
 */
@property (nonatomic,readonly) NSDictionary *sourceData;


/**
 *	@brief	字符串型的用户UID
 */
@property (nonatomic,readonly) NSString *idstr;

/**
 *	@brief	用户昵称
 */
@property (nonatomic,readonly) NSString *screenName;

/**
 *	@brief	友好显示名称
 */
@property (nonatomic,readonly) NSString *name;

/**
 *	@brief	用户所在省级ID
 */
@property (nonatomic,readonly) NSInteger province;

/**
 *	@brief	用户所在城市ID
 */
@property (nonatomic,readonly) NSInteger city;

/**
 *	@brief	用户所在地
 */
@property (nonatomic,readonly) NSString *location;

/**
 *	@brief	用户个人描述
 */
@property (nonatomic,readonly) NSString *description;

/**
 *	@brief	用户博客地址
 */
@property (nonatomic,readonly) NSString *url;

/**
 *	@brief	用户头像地址，50×50像素
 */
@property (nonatomic,readonly) NSString *profileImageUrl;

/**
 *	@brief	用户的微博统一URL地址
 */
@property (nonatomic,readonly) NSString *profileUrl;

/**
 *	@brief	用户的个性化域名
 */
@property (nonatomic,readonly) NSString *domain;

/**
 *	@brief	用户的微号
 */
@property (nonatomic,readonly) NSString *weihao;

/**
 *	@brief	性别，m：男、f：女、n：未知
 */
@property (nonatomic,readonly) NSString *gender;

/**
 *	@brief	粉丝数
 */
@property (nonatomic,readonly) NSInteger followersCount;

/**
 *	@brief	关注数
 */
@property (nonatomic,readonly) NSInteger friendsCount;

/**
 *	@brief	微博数
 */
@property (nonatomic,readonly) NSInteger statusesCount;

/**
 *	@brief	收藏数
 */
@property (nonatomic,readonly) NSInteger favouritesCount;

/**
 *	@brief	用户创建（注册）时间
 */
@property (nonatomic,readonly) NSString *createdAt;

/**
 *	@brief	暂未支持
 */
@property (nonatomic,readonly) BOOL following;

/**
 *	@brief	是否允许所有人给我发私信，true：是，false：否
 */
@property (nonatomic,readonly) BOOL allowAllActMsg;

/**
 *	@brief	是否允许标识用户的地理位置，true：是，false：否
 */
@property (nonatomic,readonly) BOOL geoEnabled;

/**
 *	@brief	是否是微博认证用户，即加V用户，true：是，false：否
 */
@property (nonatomic,readonly) BOOL verified;

/**
 *	@brief	暂未支持
 */
@property (nonatomic,readonly) NSInteger verifiedType;

/**
 *	@brief	用户备注信息，只有在查询用户关系时才返回此字段
 */
@property (nonatomic,readonly) NSString *remark;

/**
 *	@brief	用户的最近一条微博信息字段
 */
@property (nonatomic,readonly) SSSinaWeiboStatusInfoReader *status;

/**
 *	@brief	是否允许所有人对我的微博进行评论，true：是，false：否
 */
@property (nonatomic,readonly) BOOL allowAllComment;

/**
 *	@brief	用户大头像地址
 */
@property (nonatomic,readonly) NSString *avatarLarge;

/**
 *	@brief	认证原因
 */
@property (nonatomic,readonly) NSString *verifiedReason;

/**
 *	@brief	该用户是否关注当前登录用户，true：是，false：否
 */
@property (nonatomic,readonly) BOOL followMe;

/**
 *	@brief	用户的在线状态，0：不在线、1：在线
 */
@property (nonatomic,readonly) NSInteger onlineStatus;

/**
 *	@brief	用户的互粉数
 */
@property (nonatomic,readonly) NSInteger biFollowersCount;

/**
 *	@brief	用户当前的语言版本，zh-cn：简体中文，zh-tw：繁体中文，en：英语
 */
@property (nonatomic,readonly) NSString *lang;

/**
 *	@brief	初始化读取器
 *
 *	@param 	sourceData 	原数据
 *
 *	@return	读取器实例对象
 */
- (id)initWithSourceData:(NSDictionary *)sourceData;


/**
 *	@brief	创建用户信息读取器
 *
 *	@param 	sourceData 	原数据
 *
 *	@return	读取器实例对象
 */
+ (SSSinaWeiboUserInfoReader *)readerWithSourceData:(NSDictionary *)sourceData;


@end
